Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AggregateResult ¶
type AggregateResult struct {
NumCalls int64
TotalBytesReceived int64
TotalLatency time.Duration
MaxLatency time.Duration
MinLatency time.Duration
}
AggregateResult provides the aggregate result data for a set of fetches.
type ResultWithValidity ¶
type ResultWithValidity struct {
Successes AggregateResult
Failures AggregateResult
}
ResultWithValidity provides separate results for sucessful and failed fetches.
type StressResult ¶
type StressResult struct {
ResultsByUrl map[string]*ResultWithValidity
}
StressResult returns the results of a stress test.
func (*StressResult) String ¶
func (r *StressResult) String() string
String pretty-prints the key StressResult data per URL as a table.
func (*StressResult) Summary ¶
func (r *StressResult) Summary() ResultWithValidity
Summary provides the summary results over all URLs.
func (*StressResult) SummaryString ¶
func (r *StressResult) SummaryString() string
SummaryString provides aggregate statistics as a string.
Click to show internal directories.
Click to hide internal directories.